@@ -2,7 +2,7 @@ import mimetypes
 if __name__ == "__main__":
     from login import login
 else:
-    from TNAPI.login import login
+    from pytextnow.login import login
 import requests
 from datetime import datetime, time
 from dateutil.relativedelta import relativedelta
